#[non_exhaustive]pub enum AudioError {
Unsupported(String),
Misaligned {
got: usize,
expected: usize,
},
ResamplerConstruction(ResamplerConstructionError),
Resample(ResampleError),
Hang(Error),
Mux(Error),
Moq(Error),
TimeOverflow(TimeOverflow),
}Expand description
Errors returned by moq-audio.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unsupported(String)
The codec does not support this sample rate / channel combination.
Misaligned
The input buffer was not aligned to the codec’s frame size.
ResamplerConstruction(ResamplerConstructionError)
Rubato resampler construction error.
Resample(ResampleError)
Rubato resampler runtime error.
Hang(Error)
hang catalog error.
Mux(Error)
moq-mux container/transport error.
Moq(Error)
moq-net transport error.
TimeOverflow(TimeOverflow)
Timestamp overflow.